<?php
$TRANSLATIONS = array(
"Calendar" => "日曆",
"Sunday" => "星期日",
"Monday" => "星期一",
"Tuesday" => "星期二",
"Wednesday" => "星期三",
"Thursday" => "星期四",
"Friday" => "星期五",
"Saturday" => "星期六",
"January" => "一月",
"February" => "二月",
"March" => "三月",
"April" => "四月",
"May" => "五月",
"June" => "六月",
"July" => "七月",
"August" => "八月",
"September" => "九月",
"October" => "十月",
"November" => "十一月",
"December" => "十二月",
"Title" => "標題",
"Birthday" => "生日",
"Personal" => "個人",
"Work" => "工作",
"Daily" => "日",
"Weekly" => "星期",
"Date" => "日期",
"Download" => "下載",
"Edit" => "編輯",
"Delete" => "刪除",
"Share" => "分享",
"Advanced" => "進階",
"Import" => "導入",
"Unshare" => "取消分享"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
